package org.deephacks.tools4j.config.test.bean;

import com.google.common.base.Optional;
import org.deephacks.tools4j.config.model.Bean;
import org.deephacks.tools4j.config.spi.BeanManager;
import org.deephacks.tools4j.config.test.FeatureTestsRunner;
import org.deephacks.tools4j.config.test.LookupProxy;
import org.junit.Test;
import org.junit.runner.RunWith;

import java.util.List;

import static org.deephacks.tools4j.config.test.JUnitUtils.generateBeans;
import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

@RunWith(FeatureTestsRunner.class)
public class BeanManagerCreateTests {
    BeanManager manager = LookupProxy.lookup(BeanManager.class);

    @Test
    public void test_create_single() {
        List<Bean> beans = generateBeans(2, 2);
        for (Bean b : beans) {
            manager.create(b);
        }

        for (Bean b : beans) {
            Optional<Bean> r = manager.getEager(b.getId());
            assertThat(r.get(), is(b));
        }
    }

    @Test
    public void test_create_all() {
        List<Bean> beans = generateBeans(2, 2);
        manager.create(beans);
        for (Bean b : beans) {
            Optional<Bean> r = manager.getEager(b.getId());
            assertThat(r.get(), is(b));
        }
    }

    @Test
    public void test_create_default() {
        List<Bean> beans = generateBeans(2, 2);
        for (Bean bean : beans) {
            bean.setDefault();
        }
        manager.create(beans);
        for (Bean b : beans) {
            Optional<Bean> r = manager.getEager(b.getId());
            assertThat(r.get(), is(b));
            assertThat(r.get().isDefault(), is(b.isDefault()));
        }
    }

}